==> enterprisemodules-zfs_appliance-1.2.1.tar.gz: enterprisemodules-zfs_appliance-1.2.1/lib/puppet/type/zfs_share.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/zfs/core'

module Puppet
  #
  Type.newtype(:zfs_share) do
    include Puppet_X::EnterpriseModules::Zfs::Type

    desc <<-EOD
      This type allows you to manage a share on a ZFS appliance.

      Here is an example on how to use this:

          zfs_share { 'default:all/project_1/share_1':
            ensure           => 'present',
            aclinherit       => 'restricted',
            checksum         => 'fletcher4',
            compression      => 'off',
            mountpoint       => '/export/share_1',
            quota            => '0.0',
            quota_snap       => 'true',
            recordsize       => '131072.0',
            reservation      => '0.0',
            reservation_snap => 'true',
            root_group       => 'other',
            root_permissions => '700',
            root_user        => 'nobody',
            sharenfs         => 'on',
            sharesmb         => 'off',
            snapdir          => 'hidden',
          }

    EOD

    restfull_path('/api/storage/v1/pools/%{pool_name}/projects/%{project_name}/filesystems')
    restfull_type('filesystems')

    ensurable
    parameter :share_name
    parameter :appliance
    parameter :name
    parameter :pool_name
    parameter :project_name
    parameter :casesensitivity

    property :aclinherit
    property :atime
    property :checksum
    property :compression
    property :mountpoint
    property :quota
    property :quota_snap
    property :readonly
    property :recordsize
    property :reservation
    property :reservation_snap
    property :sharesmb
    property :sharenfs
    property :snapdir
    property :sharedav
    property :shareftp
    property :sharesftp
    property :sharetftp
    property :nodestroy
    property :maxblocksize
    property :root_group
    property :root_permissions
    property :root_user

    add_title_attributes(:pool_name, :project_name, :share_name) do
      /^((.*:)?(.*)\/(.*)\/(.*))$/
    end

    #
    # Autorequire the project and the appliance
    #
    autorequire(:zfs_project)  { "#{appliance}:#{pool_name}/#{project_name}" }
    autorequire(:zfs_appliance)  { appliance }

  end
end

==> enterprisemodules-zfs_appliance-1.3.0.tar.gz: enterprisemodules-zfs_appliance-1.3.0/lib/puppet/type/zfs_share.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/zfs/core'
# rubocop:disable Style/Documentation
module Puppet
  # rubocop:enable Style/Documentation
  Type.newtype(:zfs_share) do
    include Puppet_X::EnterpriseModules::Zfs::Type

    desc <<-DESC
      This type allows you to manage a share on a ZFS appliance.

      Here is an example on how to use this:

          zfs_share { 'default:all/project_1/share_1':
            ensure           => 'present',
            aclinherit       => 'restricted',
            checksum         => 'fletcher4',
            compression      => 'off',
            mountpoint       => '/export/share_1',
            quota            => '0.0',
            quota_snap       => 'true',
            recordsize       => '131072.0',
            reservation      => '0.0',
            reservation_snap => 'true',
            root_group       => 'other',
            root_permissions => '700',
            root_user        => 'nobody',
            sharenfs         => 'on',
            sharesmb         => 'off',
            snapdir          => 'hidden',
          }

    DESC

    restfull_path('/api/storage/v1/pools/%<pool_name>s/projects/%<project_name>s/filesystems')
    restfull_type('filesystems')

    ensurable
    parameter :share_name
    parameter :appliance
    parameter :name
    parameter :pool_name
    parameter :project_name
    parameter :casesensitivity

    property :aclinherit
    property :atime
    property :checksum
    property :compression
    property :mountpoint
    property :quota
    property :quota_snap
    property :readonly
    property :recordsize
    property :reservation
    property :reservation_snap
    property :sharesmb
    property :sharenfs
    property :snapdir
    property :sharedav
    property :shareftp
    property :sharesftp
    property :sharetftp
    property :nodestroy
    property :maxblocksize
    property :root_group
    property :root_permissions
    property :root_user

    add_title_attributes(:pool_name, :project_name, :share_name) do
      %r{^((.*:)?(.*)/(.*)/(.*))$}
    end

    #
    # Autorequire the project and the appliance
    #
    autorequire(:zfs_project) { "#{appliance}:#{pool_name}/#{project_name}" }
    autorequire(:zfs_appliance) { appliance }
  end
end
